[−][src]Module flat_spatial::storage
Structs
| DenseIter | |
| DenseStorage | DenseStorage stores cells in a Vec to be used for a Grid. It implements the Storage trait. |
| SparseStorage | SparseStorage stores cells in a HashMap to be used in a Grid. It is Sparse because cells are eagerly allocated, and cleaned when they are empty. It implements the Storage trait. |
| XYRange |
Traits
| Storage | The storage trait, implement this if you want to use a custom point storage for the Grid. |